@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Component/Throttle/Throttler.pm 3224 2007-10-10T08:08:59.964068Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Component/Throttle/Throttler.pm 6465 2007-04-11T12:39:35.495994Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -7,23 +7,21 @@ package Gungho::Component::Throttle::Throttler;
 use strict;
 use warnings;
 use base qw(Gungho::Component::Throttle);
+use Data::Throttler;
 
-__PACKAGE__->mk_classdata($_) for qw(throttler);
+__PACKAGE__->mk_accessors($_) for qw(throttler);
 
 sub prepare_throttler
 {
     my $self = shift;
     my %args = @_;
-
-    my $class = delete $args{throttler} || 'Data::Throttler';
-    if (! Class::Inspector->loaded($class)) {
-        $class->require or die;
-    }
-
-    $args{max_items} ||= 1000;
-    $args{interval}  ||= 3600;
-
-    $self->throttler( $class->new( %args ) );
+    $self->throttler(
+        Data::Throttler->new(
+            max_items => $args{max_items} || 1000,
+            interval  => $args{interval} || 3600,
+            db_file   => $args{db_file} || undef,
+        )
+    );
 }
 
 1;
@@ -34,10 +32,6 @@ __END__
 
 Gungho::Component::Throttle::Throttler - Data::Throttler Based Throttling
 
-=head1 SYNOPSIS
-
-  # Internal use only
-
 =head1 METHODS
 
 =head2 prepare_throttler(%args)
